==> pmb8.0.1.0.zip: pmb/opac_css/classes/searcher/searcher_sphinx_categories.class.php <==
<?php
// +-------------------------------------------------+
//  2002-2004 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: searcher_sphinx_categories.class.php,v 1.3 2024/02/28 08:30:27 rtigero Exp $

if (stristr($_SERVER['REQUEST_URI'], ".class.php")) die("no access");

require_once($class_path.'/searcher/searcher_sphinx_authorities.class.php');

class searcher_sphinx_categories extends searcher_sphinx_authorities {
	protected $index_name = 'categories';

	public function __construct($user_query){
		global $include_path;
		$this->champ_base_path = $include_path.'/indexation/authorities/categories/champs_base.xml';
		parent::__construct($user_query);
		$this->index_name = 'categories';
		$this->authority_type = AUT_TABLE_CATEG;
	}

	protected function get_filters(){
		$filters = parent::get_filters();
		global $id_thes;
		if($id_thes && ($id_thes != -1)){
			//on ne s'assure pas de savoir si c'est une chaine ou un tableau, c'est gr dans la classe racine  la vole!
			$filters[] = array(
					'name'=> 'num_thesaurus',
					'values' => intval($id_thes)
			);
		}
		return $filters;
	}

	protected function get_search_indexes(){
		global $lang, $lg_search;
		global $sphinx_indexes_prefix;
		if ($lg_search) {
			$indexes = '';
			foreach ($this->get_available_languages() as $language) {
				if ($indexes) {
					$indexes.= ',';
				}
				$indexes.= $sphinx_indexes_prefix.$this->index_name.($language ? '_'.$language : '');
			}
			return $indexes;
		}
		return $sphinx_indexes_prefix.$this->index_name.'_'.$lang.','.$sphinx_indexes_prefix.$this->index_name;
	}
}

==> pmb8.0.1.26.zip: pmb/opac_css/classes/searcher/searcher_sphinx_categories.class.php <==
<?php
// +-------------------------------------------------+
//  2002-2004 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: searcher_sphinx_categories.class.php,v 1.3.4.1 2025/10/24 14:41:22 tsamson Exp $

if (stristr($_SERVER['REQUEST_URI'], ".class.php")) die("no access");

require_once($class_path.'/searcher/searcher_sphinx_authorities.class.php');

class searcher_sphinx_categories extends searcher_sphinx_authorities {
	protected $index_name = 'categories';

	public function __construct($user_query){
		global $include_path;
		$this->champ_base_path = $include_path.'/indexation/authorities/categories/champs_base.xml';
		parent::__construct($user_query);
		$this->index_name = 'categories';
		$this->authority_type = AUT_TABLE_CATEG;
	}

	protected function get_filters(){
		$filters = parent::get_filters();
		global $id_thes;
		if($id_thes && ($id_thes != -1)){
			//on ne s'assure pas de savoir si c'est une chaine ou un tableau, c'est gr dans la classe racine  la vole!
			$filters[] = array(
					'name'=> 'num_thesaurus',
					'values' => intval($id_thes)
			);
		}
		return $filters;
	}

	protected function get_search_indexes(){
		global $lang, $lg_search;
		global $sphinx_indexes_prefix;
		if ($lg_search) {
			$indexes = '';
			foreach ($this->get_available_languages() as $language) {
				if ($indexes) {
					$indexes.= ',';
				}
				$indexes.= $sphinx_indexes_prefix.$this->index_name.($language ? '_'.$language : '');
			}
			return $indexes;
		}
		return $sphinx_indexes_prefix.$this->index_name.'_'.$lang.','.$sphinx_indexes_prefix.$this->index_name;
	}
	
	/**
	 * filtre des resultats de recherche
	 * {@inheritDoc}
	 * @see searcher::_filter_results()
	 */
	protected function _filter_results(){
	    //on ne retourne que les noeuds visibles
	    $query = "
			SELECT DISTINCT id_authority as object_id FROM authorities
			JOIN noeuds ON id_noeud = num_object AND type_object = $this->authority_type
			WHERE visible = 1 AND id_authority IN ($this->objects_ids)";
	    $results = pmb_mysql_query($query);
	    $this->objects_ids = "";
	    if (pmb_mysql_num_rows($results)) {
	        while ($rows = pmb_mysql_fetch_assoc($results)) {
	            if ($this->objects_ids) {
	                $this->objects_ids .= ',';
	            }
	            $this->objects_ids .= $rows["object_id"];
	        }
	    }
	}
}
